# 💎 cgkmc

[![Custom shields.io](https://img.shields.io/badge/docs-brightgreen?logo=github&logoColor=green&label=gh-pages)](https://jwjeffr.github.io/cgkmc/)

`cgkmc` (short for `crystal-growth-kinetic-monte-carlo`) is a package for performing crystal growth simulations using
the [Kinetic Monte Carlo](https://en.wikipedia.org/wiki/Kinetic_Monte_Carlo) method.
